/*
 * (c) Copyright 2018-2020 DESY
 *
 * This file is part of FS-DS detector software.
 *
 * This software is free: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 2 of the License, or
 * (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this software.  If not, see <http://www.gnu.org/licenses/>.
 *************************************************************************
 *     Author: Yuelong Yu <yuelong.yu@desy.de>
 */

#pragma once

#include <fsdetector/core/Globals.h>
#include <fsdetector/core/ThreadUtils.h>
#include <fsdetector/core/MemUtils.h>
#include <fsdetector/core/NetworkInterface.h>
#include <fsdetector/core/NetworkImplementation.h>
#include <fsdetector/core/FilesOperation.h>
#include <numeric>


#include "Version.h"

namespace AGIPDCtrlNS
{
    using namespace FSDetCoreNS;
    
    typedef unique_ptr<ThreadPool> uptr_threads;
    typedef shared_ptr<MemPool<int16>> sptr_mem16bit;
    typedef unique_ptr<NetworkInterface> uptr_network;
    typedef shared_ptr<NetworkInterface> sptr_network;
    typedef shared_ptr<FileOperation> sptr_fileop;

    // type of temperature sensors
    enum TEMPERATURE_SENSOR
    {
        LTCC = 0,
        ZYNC,
        FF
    };

    enum RESPONSE
    {
        SC = 0, // successful completion
        UC, // unsupported command
        UD, // unsupported device
        CE //complation error

    };
    
    // command header length
    const int32 COMMAND_HEADER_LENGTH = 6;
    
    const int16 CHAR_BUFFER = 9000;

    const int32 MAX_PACKET_LENGTH = 65535;
}
