/*
 * (c) Copyright 2018-2020 DESY
 *
 * This file is part of FS-DS detector software.
 *
 * This software is free: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 2 of the License, or
 * (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this software.  If not, see <http://www.gnu.org/licenses/>.
 *************************************************************************
 *     Author: Yuelong Yu <yuelong.yu@desy.de>
 */
#pragma once


#include "AGIPDComm.h"
#include "MockNetwork.h"

#include <fsdetector/core/FilesOperation.h>

#include <gmock/gmock.h>
#include <gtest/gtest.h>

namespace TestNS
{
    using namespace FSDetCoreNS;
    using namespace AGIPDCtrlNS;

    using namespace std;

    using ::testing::SetArgPointee;
    using ::testing::SetArgReferee;
    using ::testing::SetArrayArgument;
    using ::testing::SaveArg;
    using ::testing::AtLeast;
    using ::testing::Return;
    using ::testing::DoAll;
    using ::testing::_;

    typedef shared_ptr<MockNetwork> sptr_mocknet;
    typedef unique_ptr<AGIPDComm> uptr_agipd;

    typedef unique_ptr<FileOperation> uptr_file;

    class CtrlTest : public testing::Test
    {
    public:
        void OutputData(vector<uint8> data);
    protected:
        virtual void SetUp();
        virtual void TearDown();

        sptr_mocknet m_tcp;
        uptr_file m_file;
        uptr_agipd m_agipd;
        vector<uint8> m_output;
        string m_testdir;
        int32 m_expfilelen;
    };
    
}

